==> openjdk-11_11.0.25~5ea.orig.tar.xz: openjdk-11-11.0.25~5ea/test/lib/jdk/test/lib/security/JDKSecurityProperties.java <==
/*
 * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package jdk.test.lib.security;

import java.util.List;
import java.security.Security;

public final class JDKSecurityProperties {

    public static final List<String> jdkProps = List.of(
        "com.sun.CORBA.ORBIorTypeCheckRegistryFilter",
        "crypto.policy",
        "jceks.key.serialFilter",
        "jdk.certpath.disabledAlgorithms",
        "keystore.type",
        "krb5.kdc.bad.policy",
        "login.config",
        "networkaddress.cache.ttl",
        "ocsp.responderURL",
        "package.access",
        "policy.allowSystemProperty",
        "securerandom.drbg.config",
        "security.provider.1",
        "ssl.KeyManagerFactory.algorithm",
        "sun.rmi.registry.registryFilter"
    );

    public static List getKeys() {
        return jdkProps;
    }
}

==> openjdk-25_25~16ea.orig.tar.xz: openjdk-25-25~16ea/test/lib/jdk/test/lib/security/JDKSecurityProperties.java <==
/*
 * Copyright (c) 2018, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package jdk.test.lib.security;

import java.util.List;

public final class JDKSecurityProperties {

    public static final List<String> jdkProps = List.of(
        "crypto.policy",
        "jceks.key.serialFilter",
        "jdk.certpath.disabledAlgorithms",
        "keystore.type",
        "krb5.kdc.bad.policy",
        "login.config",
        "networkaddress.cache.ttl",
        "ocsp.responderURL",
        "package.access",
        "policy.allowSystemProperty",
        "securerandom.drbg.config",
        "security.provider.1",
        "ssl.KeyManagerFactory.algorithm",
        "sun.rmi.registry.registryFilter"
    );

    public static List<String> getKeys() {
        return jdkProps;
    }
}
